Name: zz_lang_collate
Summary: This will configure LC_COLLATE='C' for Fermilab
Version: 1.0
Release: 7
License: GPL
Group: Fermi
URL: http://fermilinux.fnal.gov/
Vendor: Fermilab
Packager: Pat Riehecky
BuildArch: noarch
Requires: glibc-common util-linux-ng policycoreutils

%description

This rpm adds the proper LC_COLLATE enviornment variable to
/etc/sysconfig/i18n to return ls output, etc, to the proper case sensitive
sort order. This will only add LC_COLLATE if it isn't already defined in
/etc/sysconfig/i18n and LANG is set to en_US.
 
%files
%post

#
# This will append a line to /etc/sysconfig/i18n if it exists and
# doesn't contain a LC_COLLATE definition and the LANG is set.
# If the LANG isn't set we are defaulting it to en_US.UTF-8
# which should do no harm and allow us to set LC_COLLATE anyway.
# If for some reason /etc/sysconfig/i18n doesn't exist, we set
# it to safe defaults.
#

file=/etc/sysconfig/i18n

# if the file is present
if [[ -f $file ]]; then
    # if the LANG is set
    if [[ $(grep -E ^LANG= $file | grep -v '#' | wc -l) -eq 1 ]]; then
        # if LC_COLLATE is not already set
        if [[ $(grep -E '^LC_COLLATE=' $file | wc -l) -eq 0 ]]; then
            # set this the way we want it
            echo 'LC_COLLATE="C"' >>$file
        fi

    elif [[ $(grep -E ^LANG= $file | grep -v '#' | wc -l) -eq 0 ]]; then
        # LANG is not set, set it so that we can proceed with a known state
        echo 'LANG="en_US.UTF-8"' >>$file
        # if LC_COLLATE is not already set
        if [[ $(grep -E '^LC_COLLATE=' $file | wc -l) -eq 0 ]]; then
            # set this the way we want it
            echo 'LC_COLLATE="C"' >>$file
        fi
    else
        # LANG is set too many times, not sure what to do other than complain
        logger -s -p daemon.warning "$file contains multiple instances of LANG"
    fi
else
    # these should be safe defaults on any system
    echo 'SYSFONT="latarcyrheb-sun16"' >$file
    echo 'LANG="en_US.UTF-8"' >>$file
    echo 'LC_COLLATE="C"' >>$file
fi

# make sure permissions and seLinux context are right
chown root:root $file
chmod 644 $file
restorecon $file >/dev/null 2>&1
 
%changelog
* Tue May 22 2012 Pat Riehecky <riehecky@fnal.gov> 1.0-7
- Updated logic for states where LANG is an unknown to avoid
  saying the work is done when it actually isn't
- Added extra logic for providing a notice when the config can't be parsed
- Ensure permissions are what you would expect for /etc/sysconfig/i18n

* Mon May 16 2011 Troy Dawson <dawson@fnal.gov> 1.0-6
- Recompiled for SLF6

